Name:           wfmath
Version:        1.0.2
Release:        12%{?dist}
Summary:        WorldForge client math libraries

Group:          Development/Libraries
License:        GPLv2+
URL:            http://worldforge.org/dev/eng/libraries/wfmath
Source0:        http://downloads.sourceforge.net/sourceforge/worldforge/%{name}-%{version}.tar.bz2

BuildRequires:  pkgconfig doxygen
# Testing needs
BuildRequires:  atlascpp-devel

%description
WFMath provides mathematical functions for WorldForge clients.  The primary
focus of WFMath is geometric objects. Thus, it includes several shapes (boxes,
balls, lines), in addition to the basic math objects that are used to build
these shapes (points, vectors, matrices). WFMath provides a means for other
system compenents to pass geometric information around in a common format.


%package        devel
Summary:        Development files for wfmath
Group:          Development/Libraries
Requires:       pkgconfig %{name} = %{version}-%{release}


%description    devel
Libraries and header files for developing applications that use wfmath.


%prep
%setup -q


%build
# tests fail when build with -O2 on these arches
%ifarch s390 s390x
CXXFLAGS="%{optflags} -O0" \
%endif
%configure --disable-static
make %{?_smp_mflags}

make docs
# Rename a messed-up man page
mv doc/man/man3/WFMath_Polygon_* doc/man/man3/WFMath_Polygon_2.3
# Delete a messed-up man page that sometimes appears
rm -f doc/man/man3/*_.3

# Remove timestamps from the generated documentation to avoid
# multiarch conflicts

for file in doc/html/*.html ; do
    sed -i -e 's/Generated on .* for WFMath by/Generated for WFMath by/' $file
done

%install
make install DESTDIR=$RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT%{_mandir}/man3/
install -p -m0644 doc/man/man3/*.3 $RPM_BUILD_ROOT%{_mandir}/man3/

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la


%check
# Run tests in debug mode so asserts won't be skipped
sed -i -e 's/-DNDEBUG/-DDEBUG/' wfmath/Makefile
make %{?_smp_mflags} check

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%doc AUTHORS COPYING README TODO ChangeLog
%{_libdir}/lib%{name}-1.0.so.*


%files devel
%doc doc/CLASS_LAYOUT doc/html/
%{_includedir}/%{name}-1.0
%{_libdir}/lib%{name}-1.0.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.gz


%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Mon Jul 31 2017 Filipe Rosset <rosset.filipe@gmail.com> - 1.0.2-10
- Rebuilt for atlascpp 0.6.4 plus spec cleanup

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.0.2-4
- Rebuilt for GCC 5 C++11 ABI change

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 16 2014 Filipe Rosset <rosset.filipe@gmail.com> - 1.0.2-1
- Rebuilt for new upstream version 1.0.2, fix spec to meet guidelines + spec cleanup
- Fix rhbz #805470 and #926717

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Nov 14 2012 Tom Callaway <spot@fedoraproject.org> - 1.0.1-1
- update to 1.0.1

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.12-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Jan 22 2012 Bruno Wolff III <bruno@wolff.to> 0.3.12-1
- Upstream release 0.3.12
- gcc patches no longer needed

* Mon Jan 16 2012 Bruno Wolff III <bruno@wolff.to> 0.3.11-4
- gcc 4.7 requires math.h to be included now in a couple of places

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.11-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat May 07 2011 Bruno Wolff III <bruno@wolff.to> 0.3.11-1
- Upstream update to 0.3.11

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Oct  1 2010 Dan Horák <dan[at]danny.cz> 0.3.9-3
- enable tests on ppc(64)
- build with -O0 on s390(x), with -O2 the shape_test fails

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Feb 27 2009 Alexey Torkhov <atorkhov@gmail.com> 0.3.9-1
- Update to 0.3.9

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Dec 14 2008 Alexey Torkhov <atorkhov@gmail.com> 0.3.8-1
- Update to 0.3.8
- Don't run unit tests on PPC64

* Sat Feb 9 2008 Wart <wart at kobold.org> 0.3.7-2
- Rebuild for gcc 4.3

* Sat Dec 15 2007 Wart <wart at kobold.org> 0.3.7-1
- Update to 0.3.7
- Remove dates from doc files to avoid multiarch conflicts (BZ #343421)

* Tue Aug 21 2007 Wart <wart at kobold.org> 0.3.6-3
- License tag clarification

* Wed Jul 25 2007 Jeremy Katz <katzj@redhat.com> - 0.3.6-2
- rebuild for toolchain bug

* Sun Jul 22 2007 Wart <wart at kobold.org> 0.3.6-1
- Update to 0.3.6

* Sun Aug 27 2006 Wart <wart at kobold.org> 0.3.5-2
- Bump release to fix cvs tags

* Fri Aug 25 2006 Wart <wart at kobold.org> 0.3.5-1
- Update to 0.3.5
- Remove patch that has been added upstream 

* Thu Jul 27 2006 Wart <wart at kobold.org> 0.3.4-4
- Disable tests on ppc

* Thu Jul 20 2006 Wart <wart at kobold.org> 0.3.4-3
- Add smp_mflags to %%check

* Wed Jul 19 2006 Wart <wart at kobold.org> 0.3.4-2
- Added patch to fix test failures on x86_64
- Add 'make check'
- Add missing Requires: pkgconfig to -devel subpackage

* Wed Jun 14 2006 Wart <wart at kobold.org> 0.3.4-1
- Initial spec file for Fedora Extras
